# RuleScopeEnum

When this rule applies. * Rules scoped to `anyone` apply regardless of whether the user is authenticated. * Rules scoped to `assigned_to_user` apply only to users who have been assigned the rule,   e.g. via  role. * Rules scoped to `any_known_user` apply to any user who has authenticated with the   system. * Rules scoped to `any_app_user` apply to any user who has a role in the owning   application. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


